determine_ref_and_parens

Function determine_ref_and_parens 

pub(crate) fn determine_ref_and_parens(
    ctx: &AssistContext<'_, '_>,
    field_expr: &FieldExpr,
) -> (Expr, RefData)
Decides whether the new path expression needs to be dereferenced and/or wrapped in parens. Returns the relevant parent expression to replace and the RefData.